@@ -14,7 +14,7 @@ var texts = {
     linksattributes: "Link attributes",
     noitemsselected: "No items selected",
     alertnonodes: "No nodes selected! Hold shift to select nodes.",
-    alertnonodestable: "No nodes selected in table!",
+    alertnonodestable: "Anything matched in table!",
     repulsion: "Repulsion",
     distance: "Distance",
     loading: "Loading...",
@@ -24,6 +24,8 @@ var texts = {
     showhideaxes: "Show/hide axes",
     showhideimages: "Show/hide images",
     showhidesidebar: "Show/hide sidebar",
+    showhidebuttons: "Show/hide buttons",
+    showhidetables: "Show/hide tables",
     stopresume: "Stop/resume",
     netheatmap: "Net/heatmap",
     isolateselection: "Filter selection",
@@ -44,12 +46,14 @@ var texts = {
     ofsomeone: "of",
     withsomeone: "with",
     incidences: "Incidences",
-    ltexpected: "< Expected",
-    gtexpected: "> Expected",
-    confidence: "Confidence interval",
-    subjectselect: "Event selection",
+    expected: "Expected",
+    expectedconfidence: "+/- Expected confidence",
+    confidenceinterval: "+/- Confidence interval",
+    subjectselect: "Event",
     Label: "Label",
+    LabelSize: "Lab.Size",
     Group: "Group",
+    Order: "Order",
     OrderA: "A Order",
     OrderD: "D Order",
     Size: "Size",
@@ -70,5 +74,10 @@ var texts = {
     "triangle-up": "triangle-up",
     trianglesquare: "Triangle/square",
     selectacolorscale: "Select a color scale for ",
-    outof: "out of"
+    outof: "out of",
+    scenarios: "Number of scenarios",
+    resetzoom: "Reset zoom",
+    removefilter: "Remove filter",
+    alertrecordheatmap: "Heatmap cannot be recorded.",
+    speed: "Speed"
   };
